@@ -20,33 +20,33 @@
 
 #include "cvsjob.h"
 
-#include "sshagent.h"
 #include "../debug.h"
+#include "sshagent.h"
 
-#include <QDebug>
 #include <kprocess.h>
 
 #include <cvsjobadaptor.h>
 
-
-struct CvsJob::Private
-{
-    Private() : isRunning(false)
+struct CvsJob::Private {
+    Private()
+        : isRunning(false)
     {
         childproc = new KProcess;
     }
-    ~Private() { delete childproc; }
+    ~Private()
+    {
+        delete childproc;
+    }
 
-    KProcess*   childproc;
-    QString     server;
-    QString     rsh;
-    QString     directory;
-    bool        isRunning;
+    KProcess *childproc;
+    QString server;
+    QString rsh;
+    QString directory;
+    bool isRunning;
     QStringList outputLines;
-    QString     dbusObjectPath;
+    QString dbusObjectPath;
 };
 
-
 CvsJob::CvsJob(unsigned jobNum)
     : QObject()
     , d(new Private)
@@ -55,22 +55,20 @@ CvsJob::CvsJob(unsigned jobNum)
     QDBusConnection dbus = QDBusConnection::sessionBus();
     d->dbusObjectPath = "/CvsJob" + QString::number(jobNum);
     qCDebug(log_cervisia) << "dbusObjectPath:" << d->dbusObjectPath;
-    dbus.registerObject( d->dbusObjectPath, this );
+    dbus.registerObject(d->dbusObjectPath, this);
 }
 
-
-CvsJob::CvsJob(const QString& objId)
+CvsJob::CvsJob(const QString &objId)
     : QObject()
     , d(new Private)
 {
     (void)new CvsjobAdaptor(this);
-    //TODO register it with good name
+    // TODO register it with good name
     d->dbusObjectPath = '/' + objId;
     qCDebug(log_cervisia) << "dbusObjectPath:" << d->dbusObjectPath;
-    QDBusConnection::sessionBus().registerObject( d->dbusObjectPath, this );
+    QDBusConnection::sessionBus().registerObject(d->dbusObjectPath, this);
 }
 
-
 CvsJob::~CvsJob()
 {
     delete d;
@@ -78,7 +76,7 @@ CvsJob::~CvsJob()
 
 QString CvsJob::dbusObjectPath() const
 {
-   return d->dbusObjectPath;
+    return d->dbusObjectPath;
 }
 
 void CvsJob::clearCvsCommand()
@@ -86,70 +84,59 @@ void CvsJob::clearCvsCommand()
     d->childproc->clearProgram();
 }
 
-
-void CvsJob::setRSH(const QString& rsh)
+void CvsJob::setRSH(const QString &rsh)
 {
     d->rsh = rsh;
 }
 
-
-void CvsJob::setServer(const QString& server)
+void CvsJob::setServer(const QString &server)
 {
     d->server = server;
 }
 
-
-void CvsJob::setDirectory(const QString& directory)
+void CvsJob::setDirectory(const QString &directory)
 {
     d->directory = directory;
 }
 
-
 bool CvsJob::isRunning() const
 {
     return d->isRunning;
 }
 
-
-CvsJob& CvsJob::operator<<(const QString& arg)
+CvsJob &CvsJob::operator<<(const QString &arg)
 {
     *d->childproc << arg;
     return *this;
 }
 
-
-CvsJob& CvsJob::operator<<(const char* arg)
+CvsJob &CvsJob::operator<<(const char *arg)
 {
     *d->childproc << arg;
     return *this;
 }
 
-
-CvsJob& CvsJob::operator<<(const QStringList& args)
+CvsJob &CvsJob::operator<<(const QStringList &args)
 {
     *d->childproc << args;
     return *this;
 }
 
-
 QString CvsJob::cvsCommand() const
 {
     return d->childproc->program().join(QLatin1String(" "));
 }
 
-
 QStringList CvsJob::output() const
 {
     return d->outputLines;
 }
 
-
 bool CvsJob::execute()
 {
     // setup job environment to use the ssh-agent (if it is running)
     SshAgent ssh;
-    if( !ssh.pid().isEmpty() )
-    {
+    if (!ssh.pid().isEmpty()) {
         // qCDebug(log_cervisia) << "PID  = " << ssh.pid();
         // qCDebug(log_cervisia) << "SOCK = " << ssh.authSock();
 
@@ -159,21 +146,18 @@ bool CvsJob::execute()
 
     d->childproc->setEnv("SSH_ASKPASS", "cvsaskpass");
 
-    if( !d->rsh.isEmpty() )
+    if (!d->rsh.isEmpty())
         d->childproc->setEnv("CVS_RSH", d->rsh);
 
-    if( !d->server.isEmpty() )
+    if (!d->server.isEmpty())
         d->childproc->setEnv("CVS_SERVER", d->server);
 
-    if( !d->directory.isEmpty() )
+    if (!d->directory.isEmpty())
         d->childproc->setWorkingDirectory(d->directory);
 
-    connect(d->childproc, SIGNAL(finished(int,QProcess::ExitStatus)),
-        SLOT(slotProcessFinished()));
-    connect(d->childproc, SIGNAL(readyReadStandardOutput()),
-        SLOT(slotReceivedStdout()));
-    connect(d->childproc, SIGNAL(readyReadStandardError()),
-        SLOT(slotReceivedStderr()));
+    connect(d->childproc, SIGNAL(finished(int, QProcess::ExitStatus)), SLOT(slotProcessFinished()));
+    connect(d->childproc, SIGNAL(readyReadStandardOutput()), SLOT(slotReceivedStdout()));
+    connect(d->childproc, SIGNAL(readyReadStandardError()), SLOT(slotReceivedStderr()));
 
     qCDebug(log_cervisia) << "Execute cvs command:" << cvsCommand();
 
@@ -184,7 +168,6 @@ bool CvsJob::execute()
     return d->childproc->waitForStarted();
 }
 
-
 void CvsJob::cancel()
 {
     d->childproc->kill();
@@ -202,7 +185,6 @@ void CvsJob::slotProcessFinished()
     emit jobExited(d->childproc->exitStatus() == QProcess::NormalExit, d->childproc->exitCode());
 }
 
-
 void CvsJob::slotReceivedStdout()
 {
     const QString output(QString::fromLocal8Bit(d->childproc->readAllStandardOutput()));
@@ -214,7 +196,6 @@ void CvsJob::slotReceivedStdout()
     emit receivedStdout(output);
 }
 
-
 void CvsJob::slotReceivedStderr()
 {
     const QString output(QString::fromLocal8Bit(d->childproc->readAllStandardError()));
@@ -225,4 +206,3 @@ void CvsJob::slotReceivedStderr()
     qCDebug(log_cervisia) << "output:" << output;
     emit receivedStderr(output);
 }
-
