@@ -20,36 +20,34 @@
 
 #include "settingsdialog.h"
 
+#include <QDialogButtonBox>
+#include <QFontDialog>
+#include <QLineEdit>
+#include <QPushButton>
+#include <QVBoxLayout>
 #include <qcheckbox.h>
 #include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qwidget.h>
 #include <qradiobutton.h>
-#include <QVBoxLayout>
-#include <QDialogButtonBox>
-#include <QPushButton>
-#include <QFontDialog>
-#include <QLineEdit>
+#include <qwidget.h>
 
+#include <KConfigGroup>
+#include <KHelpClient>
 #include <kcolorbutton.h>
 #include <kconfig.h>
 #include <kurlrequester.h>
-#include <KConfigGroup>
-#include <KHelpClient>
 
-#include "misc.h"
 #include "cervisiasettings.h"
+#include "misc.h"
 #include "ui_settingsdialog_advanced.h"
 
-
-FontButton::FontButton( const QString &text, QWidget *parent )
+FontButton::FontButton(const QString &text, QWidget *parent)
     : QPushButton(text, parent)
 {
-    connect( this, SIGNAL(clicked()), this, SLOT(chooseFont()) );
+    connect(this, SIGNAL(clicked()), this, SLOT(chooseFont()));
 }
 
-
 void FontButton::chooseFont()
 {
     QFont newFont(font());
@@ -58,20 +56,19 @@ void FontButton::chooseFont()
 
     QFontDialog::getFont(&ok, newFont, this);
 
-    if ( !ok )
+    if (!ok)
         return;
 
     setFont(newFont);
     repaint();
 }
 
-
 SettingsDialog::SettingsDialog(KConfig *conf, QWidget *parent)
     : KPageDialog(parent)
 {
-    setFaceType( List );
+    setFaceType(List);
     setWindowTitle(i18n("Configure Cervisia"));
-    setStandardButtons(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::Help);
+    setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
 
     QPushButton *okButton = button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -117,22 +114,18 @@ SettingsDialog::~SettingsDialog()
     delete serviceConfig;
 }
 
-
 void SettingsDialog::slotHelp()
 {
-  KHelpClient::invokeHelp(QLatin1String("customization"));
+    KHelpClient::invokeHelp(QLatin1String("customization"));
 }
 
-
 void SettingsDialog::readSettings()
 {
     // read entries from cvs D-Bus service configuration
     KConfigGroup group = serviceConfig->group("General");
     cvspathedit->setUrl(group.readPathEntry("CVSPath", "cvs"));
-    m_advancedPage->kcfg_Compression->setValue(group.readEntry(
-                                                   "Compression", 0));
-    m_advancedPage->kcfg_UseSshAgent->setChecked(group.readEntry(
-                                                   "UseSshAgent", false));
+    m_advancedPage->kcfg_Compression->setValue(group.readEntry("Compression", 0));
+    m_advancedPage->kcfg_UseSshAgent->setChecked(group.readEntry("UseSshAgent", false));
 
     group = config->group("General");
     m_advancedPage->kcfg_Timeout->setValue(CervisiaSettings::timeout());
@@ -151,7 +144,7 @@ void SettingsDialog::readSettings()
     m_annotateFontBox->setFont(CervisiaSettings::annotateFont());
     m_diffFontBox->setFont(CervisiaSettings::diffFont());
     m_changelogFontBox->setFont(CervisiaSettings::changeLogFont());
-    m_splitterBox->setChecked(group.readEntry("SplitHorizontally",true));
+    m_splitterBox->setChecked(group.readEntry("SplitHorizontally", true));
 
     m_conflictButton->setColor(CervisiaSettings::conflictColor());
     m_localChangeButton->setColor(CervisiaSettings::localChangeColor());
@@ -163,16 +156,13 @@ void SettingsDialog::readSettings()
     m_diffDeleteButton->setColor(CervisiaSettings::diffDeleteColor());
 }
 
-
 void SettingsDialog::writeSettings()
 {
     // write entries to cvs D-Bus service configuration
     KConfigGroup group = serviceConfig->group("General");
     group.writePathEntry("CVSPath", cvspathedit->text());
-    group.writeEntry("Compression",
-        m_advancedPage->kcfg_Compression->value());
-    group.writeEntry("UseSshAgent",
-        m_advancedPage->kcfg_UseSshAgent->isChecked());
+    group.writeEntry("Compression", m_advancedPage->kcfg_Compression->value());
+    group.writeEntry("UseSshAgent", m_advancedPage->kcfg_UseSshAgent->isChecked());
 
     // write to disk so other services can reparse the configuration
     serviceConfig->sync();
@@ -216,19 +206,18 @@ void SettingsDialog::done(int res)
     QDialog::done(res);
 }
 
-
 /*
  * Create a page for the general options
  */
 void SettingsDialog::addGeneralPage()
 {
-    QFrame* generalPage = new QFrame;
-    KPageWidgetItem *page = new KPageWidgetItem( generalPage, i18n("General") );
-    page->setIcon( QIcon::fromTheme("applications-system") );
-    
-    QVBoxLayout* layout = new QVBoxLayout(generalPage);
+    auto generalPage = new QFrame;
+    auto page = new KPageWidgetItem(generalPage, i18n("General"));
+    page->setIcon(QIcon::fromTheme("applications-system"));
 
-    QLabel *usernamelabel = new QLabel( i18n("&User name for the change log editor:"), generalPage );
+    auto layout = new QVBoxLayout(generalPage);
+
+    auto usernamelabel = new QLabel(i18n("&User name for the change log editor:"), generalPage);
     usernameedit = new QLineEdit(generalPage);
     usernameedit->setFocus();
     usernamelabel->setBuddy(usernameedit);
@@ -236,7 +225,7 @@ void SettingsDialog::addGeneralPage()
     layout->addWidget(usernamelabel);
     layout->addWidget(usernameedit);
 
-    QLabel *cvspathlabel = new QLabel( i18n("&Path to CVS executable, or 'cvs':"), generalPage );
+    auto cvspathlabel = new QLabel(i18n("&Path to CVS executable, or 'cvs':"), generalPage);
     cvspathedit = new KUrlRequester(generalPage);
     cvspathlabel->setBuddy(cvspathedit);
 
@@ -248,19 +237,18 @@ void SettingsDialog::addGeneralPage()
     addPage(page);
 }
 
-
 /*
  * Create a page for the diff optionsw
  */
 void SettingsDialog::addDiffPage()
 {
-    QFrame* diffPage = new QFrame;
-    KPageWidgetItem *page = new KPageWidgetItem( diffPage, i18n("Diff Viewer") );
-    page->setIcon( QIcon::fromTheme("vcs-diff-cvs-cervisia") );
+    auto diffPage = new QFrame;
+    auto page = new KPageWidgetItem(diffPage, i18n("Diff Viewer"));
+    page->setIcon(QIcon::fromTheme("vcs-diff-cvs-cervisia"));
 
-    QGridLayout* layout = new QGridLayout(diffPage);
+    auto layout = new QGridLayout(diffPage);
 
-    QLabel *contextlabel = new QLabel( i18n("&Number of context lines in diff dialog:"), diffPage );
+    auto contextlabel = new QLabel(i18n("&Number of context lines in diff dialog:"), diffPage);
     contextedit = new QSpinBox(diffPage);
     contextedit->setRange(0, 65535);
     contextlabel->setBuddy(contextedit);
@@ -268,14 +256,14 @@ void SettingsDialog::addDiffPage()
     layout->addWidget(contextlabel, 0, 0);
     layout->addWidget(contextedit, 0, 1);
 
-    QLabel *diffoptlabel = new QLabel(i18n("Additional &options for cvs diff:"), diffPage);
+    auto diffoptlabel = new QLabel(i18n("Additional &options for cvs diff:"), diffPage);
     diffoptedit = new QLineEdit(diffPage);
     diffoptlabel->setBuddy(diffoptedit);
 
     layout->addWidget(diffoptlabel, 1, 0);
     layout->addWidget(diffoptedit, 1, 1);
 
-    QLabel *tabwidthlabel = new QLabel(i18n("Tab &width in diff dialog:"), diffPage);
+    auto tabwidthlabel = new QLabel(i18n("Tab &width in diff dialog:"), diffPage);
     tabwidthedit = new QSpinBox(diffPage);
     tabwidthedit->setRange(1, 16);
     tabwidthlabel->setBuddy(tabwidthedit);
@@ -283,7 +271,7 @@ void SettingsDialog::addDiffPage()
     layout->addWidget(tabwidthlabel, 2, 0);
     layout->addWidget(tabwidthedit, 2, 1);
 
-    QLabel *extdifflabel = new QLabel(i18n("External diff &frontend:"), diffPage);
+    auto extdifflabel = new QLabel(i18n("External diff &frontend:"), diffPage);
     extdiffedit = new KUrlRequester(diffPage);
     extdifflabel->setBuddy(extdiffedit);
 
@@ -295,21 +283,22 @@ void SettingsDialog::addDiffPage()
     addPage(page);
 }
 
-
 /*
  * Create a page for the status options
  */
 void SettingsDialog::addStatusPage()
 {
-    QWidget* statusPage = new QWidget;
-    QVBoxLayout *statusPageVBoxLayout = new QVBoxLayout(statusPage);
-    KPageWidgetItem *page = new KPageWidgetItem( statusPage, i18n("Status") );
-    page->setIcon( QIcon::fromTheme("fork") );
+    auto statusPage = new QWidget;
+    auto statusPageVBoxLayout = new QVBoxLayout(statusPage);
+    auto page = new KPageWidgetItem(statusPage, i18n("Status"));
+    page->setIcon(QIcon::fromTheme("fork"));
 
     remotestatusbox = new QCheckBox(i18n("When opening a sandbox from a &remote repository,\n"
-                                         "start a File->Status command automatically"), statusPage);
+                                         "start a File->Status command automatically"),
+                                    statusPage);
     localstatusbox = new QCheckBox(i18n("When opening a sandbox from a &local repository,\n"
-                                        "start a File->Status command automatically"), statusPage);
+                                        "start a File->Status command automatically"),
+                                   statusPage);
 
     statusPageVBoxLayout->addWidget(remotestatusbox);
     statusPageVBoxLayout->addWidget(localstatusbox);
@@ -318,15 +307,14 @@ void SettingsDialog::addStatusPage()
     addPage(page);
 }
 
-
 /*
  * Create a page for the advanced options
  */
 void SettingsDialog::addAdvancedPage()
 {
-    QWidget* frame = new QWidget;
-    KPageWidgetItem *page = new KPageWidgetItem( frame, i18n("Advanced") );
-    page->setIcon( QIcon::fromTheme("configure") );
+    auto frame = new QWidget;
+    auto page = new KPageWidgetItem(frame, i18n("Advanced"));
+    page->setIcon(QIcon::fromTheme("configure"));
 
     m_advancedPage = new Ui::AdvancedPage;
     m_advancedPage->setupUi(frame);
@@ -337,82 +325,77 @@ void SettingsDialog::addAdvancedPage()
     addPage(page);
 }
 
-
 /*
  * Create a page for the look & feel options
  */
 void SettingsDialog::addLookAndFeelPage()
 {
-    QWidget* lookPage = new QWidget;
-    QVBoxLayout *lookPageVBoxLayout = new QVBoxLayout(lookPage);
-    KPageWidgetItem *page = new KPageWidgetItem( lookPage, i18n("Appearance") );
-    page->setIcon( QIcon::fromTheme("preferences-desktop-theme") );
+    auto lookPage = new QWidget;
+    auto lookPageVBoxLayout = new QVBoxLayout(lookPage);
+    auto page = new KPageWidgetItem(lookPage, i18n("Appearance"));
+    page->setIcon(QIcon::fromTheme("preferences-desktop-theme"));
 
-    QGroupBox* fontGroupBox = new QGroupBox(i18n("Fonts"), lookPage);
+    auto fontGroupBox = new QGroupBox(i18n("Fonts"), lookPage);
     lookPageVBoxLayout->addWidget(fontGroupBox);
 
-    m_protocolFontBox  = new FontButton(i18n("Font for &Protocol Window..."),
-                                        fontGroupBox);
-    m_annotateFontBox  = new FontButton(i18n("Font for A&nnotate View..."),
-                                        fontGroupBox);
-    m_diffFontBox      = new FontButton(i18n("Font for D&iff View..."),
-                                        fontGroupBox);
-    m_changelogFontBox = new FontButton(i18n("Font for ChangeLog View..."),
-                                        fontGroupBox);
+    m_protocolFontBox = new FontButton(i18n("Font for &Protocol Window..."), fontGroupBox);
+    m_annotateFontBox = new FontButton(i18n("Font for A&nnotate View..."), fontGroupBox);
+    m_diffFontBox = new FontButton(i18n("Font for D&iff View..."), fontGroupBox);
+    m_changelogFontBox = new FontButton(i18n("Font for ChangeLog View..."), fontGroupBox);
 
-    QVBoxLayout* fontLayout( new QVBoxLayout( fontGroupBox ) );
-    fontLayout->addWidget( m_protocolFontBox );
-    fontLayout->addWidget( m_annotateFontBox );
-    fontLayout->addWidget( m_diffFontBox );
-    fontLayout->addWidget( m_changelogFontBox );
+    auto fontLayout(new QVBoxLayout(fontGroupBox));
+    fontLayout->addWidget(m_protocolFontBox);
+    fontLayout->addWidget(m_annotateFontBox);
+    fontLayout->addWidget(m_diffFontBox);
+    fontLayout->addWidget(m_changelogFontBox);
 
-    QGroupBox* colorGroupBox = new QGroupBox(i18n("Colors"), lookPage);
+    auto colorGroupBox = new QGroupBox(i18n("Colors"), lookPage);
     lookPageVBoxLayout->addWidget(colorGroupBox);
 
-    QLabel* conflictLabel = new QLabel(i18n("Conflict:"), colorGroupBox);
-    m_conflictButton      = new KColorButton(colorGroupBox);
+    auto conflictLabel = new QLabel(i18n("Conflict:"), colorGroupBox);
+    m_conflictButton = new KColorButton(colorGroupBox);
     conflictLabel->setBuddy(m_conflictButton);
 
-    QLabel* diffChangeLabel = new QLabel(i18n("Diff change:"), colorGroupBox);
-    m_diffChangeButton      = new KColorButton(colorGroupBox);
+    auto diffChangeLabel = new QLabel(i18n("Diff change:"), colorGroupBox);
+    m_diffChangeButton = new KColorButton(colorGroupBox);
     diffChangeLabel->setBuddy(m_diffChangeButton);
 
-    QLabel* localChangeLabel = new QLabel(i18n("Local change:"), colorGroupBox);
-    m_localChangeButton      = new KColorButton(colorGroupBox);
+    auto localChangeLabel = new QLabel(i18n("Local change:"), colorGroupBox);
+    m_localChangeButton = new KColorButton(colorGroupBox);
     localChangeLabel->setBuddy(m_localChangeButton);
 
-    QLabel* diffInsertLabel = new QLabel(i18n("Diff insertion:"), colorGroupBox);
-    m_diffInsertButton      = new KColorButton(colorGroupBox);
+    auto diffInsertLabel = new QLabel(i18n("Diff insertion:"), colorGroupBox);
+    m_diffInsertButton = new KColorButton(colorGroupBox);
     diffInsertLabel->setBuddy(m_diffInsertButton);
 
-    QLabel* remoteChangeLabel = new QLabel(i18n("Remote change:"), colorGroupBox);
-    m_remoteChangeButton      = new KColorButton(colorGroupBox);
-    remoteChangeLabel->setBuddy( m_remoteChangeButton );
+    auto remoteChangeLabel = new QLabel(i18n("Remote change:"), colorGroupBox);
+    m_remoteChangeButton = new KColorButton(colorGroupBox);
+    remoteChangeLabel->setBuddy(m_remoteChangeButton);
 
-    QLabel* diffDeleteLabel = new QLabel(i18n("Diff deletion:"), colorGroupBox);
-    m_diffDeleteButton      = new KColorButton(colorGroupBox);
+    auto diffDeleteLabel = new QLabel(i18n("Diff deletion:"), colorGroupBox);
+    m_diffDeleteButton = new KColorButton(colorGroupBox);
     diffDeleteLabel->setBuddy(m_diffDeleteButton);
 
-    QLabel* notInCvsLabel = new QLabel(i18n("Not in cvs:"), colorGroupBox);
-    m_notInCvsButton      = new KColorButton(colorGroupBox);
+    auto notInCvsLabel = new QLabel(i18n("Not in cvs:"), colorGroupBox);
+    m_notInCvsButton = new KColorButton(colorGroupBox);
     notInCvsLabel->setBuddy(m_notInCvsButton);
 
-    QGridLayout* colorLayout( new QGridLayout( colorGroupBox ) );
-    colorLayout->addWidget( conflictLabel, 0, 0 );
-    colorLayout->addWidget( m_conflictButton, 0, 1 );
-    colorLayout->addWidget( localChangeLabel, 1, 0 );
-    colorLayout->addWidget( m_localChangeButton, 1, 1 );
-    colorLayout->addWidget( remoteChangeLabel, 2, 0 );
-    colorLayout->addWidget( m_remoteChangeButton, 2, 1 );
-    colorLayout->addWidget( notInCvsLabel, 3, 0 );
-    colorLayout->addWidget( m_notInCvsButton, 3, 1 );
+    auto colorLayout(new QGridLayout(colorGroupBox));
+    colorLayout->addWidget(conflictLabel, 0, 0);
+    colorLayout->addWidget(m_conflictButton, 0, 1);
+    colorLayout->addWidget(localChangeLabel, 1, 0);
+    colorLayout->addWidget(m_localChangeButton, 1, 1);
+    colorLayout->addWidget(remoteChangeLabel, 2, 0);
+    colorLayout->addWidget(m_remoteChangeButton, 2, 1);
+    colorLayout->addWidget(notInCvsLabel, 3, 0);
+    colorLayout->addWidget(m_notInCvsButton, 3, 1);
 
-    colorLayout->addWidget( diffChangeLabel, 0, 3 );
-    colorLayout->addWidget( m_diffChangeButton, 0, 4 );
-    colorLayout->addWidget( diffInsertLabel, 1, 3 );
-    colorLayout->addWidget( m_diffInsertButton, 1, 4 );
-    colorLayout->addWidget( diffDeleteLabel, 2, 3 );
-    colorLayout->addWidget( m_diffDeleteButton, 2, 4 );
+    colorLayout->addWidget(diffChangeLabel, 0, 3);
+    colorLayout->addWidget(m_diffChangeButton, 0, 4);
+    colorLayout->addWidget(diffInsertLabel, 1, 3);
+    colorLayout->addWidget(m_diffInsertButton, 1, 4);
+    colorLayout->addWidget(diffDeleteLabel, 2, 3);
+    colorLayout->addWidget(m_diffDeleteButton, 2, 4);
 
     m_splitterBox = new QCheckBox(i18n("Split main window &horizontally"), lookPage);
     lookPageVBoxLayout->addWidget(m_splitterBox);
@@ -420,8 +403,6 @@ void SettingsDialog::addLookAndFeelPage()
     addPage(page);
 }
 
-
-
 // Local Variables:
 // c-basic-offset: 4
 // End:
